@@ -10,15 +10,15 @@
 #' The confidence level to use for the confidence interval (between `0` ans `1`).
 #' @param ... Additional parameters passed to [parameters::model_parameters()].
 #' @note
-#' For [betareg::betareg()], the component column in the results is standardized
-#' with [broom::tidy()], using `"mean"` and `"precision"` values.
+#' For [betareg::betareg()] models, the component column in the results is
+#' standardized with [broom::tidy()], using `"mean"` and `"precision"` values.
 #' @examplesIf .assert_package("parameters", boolean = TRUE)
 #' \donttest{
 #'   lm(Sepal.Length ~ Sepal.Width + Species, data = iris) |>
 #'     tidy_parameters()
 #' }
 #' @export
-#' @family custom_tieders
+#' @family custom_tidiers
 tidy_parameters <- function(x, conf.int = TRUE, conf.level = .95, ...) {
   .assert_package("parameters", fn = "broom.helpers::tidy_parameters()")
   args <- list(...)
@@ -81,8 +81,12 @@ tidy_parameters <- function(x, conf.int = TRUE, conf.level = .95, ...) {
 #' The confidence level to use for the confidence interval (between `0` ans `1`).
 #' @param ... Additional parameters passed to `broom::tidy()` or
 #' `parameters::model_parameters()`.
+#' @note
+#' For [quantreg::rq()] models, if the result contains several *tau* values,
+#' a `"component"` column is added and populated
+#' with the value of the `"tau"` column.
 #' @export
-#' @family custom_tieders
+#' @family custom_tidiers
 tidy_with_broom_or_parameters <- function(x, conf.int = TRUE, conf.level = .95, ...) {
   exponentiate_later <- FALSE
 
@@ -136,6 +140,15 @@ tidy_with_broom_or_parameters <- function(x, conf.int = TRUE, conf.level = .95,
     return(tidy_vgam(x, conf.int = conf.int, conf.level = conf.level, ...))
   }
 
+  if (inherits(x, "svy_vglm")) {
+    cli::cli_alert_info("{.cls svy_vglm} model detected.")
+    cli::cli_alert_success("{.fn tidy_svy_vglm} used instead.")
+    cli::cli_alert_info(
+      "Add {.code tidy_fun = broom.helpers::tidy_svy_vglm} to quiet these messages."
+    )
+    return(tidy_svy_vglm(x, conf.int = conf.int, conf.level = conf.level, ...))
+  }
+
   tidy_args <- list(...)
   tidy_args$x <- x
   tidy_args$conf.int <- conf.int
@@ -143,7 +156,9 @@ tidy_with_broom_or_parameters <- function(x, conf.int = TRUE, conf.level = .95,
 
   # class of models known for tidy() not supporting exponentiate argument
   # and for ignoring it
-  if (any(c("fixest", "plm", "felm", "lavaan", "nls", "survreg") %in% class(x))) {
+  mods_no_exp <-
+    c("fixest", "plm", "felm", "lavaan", "nls", "survreg")
+  if (any(mods_no_exp %in% class(x))) {
     if (isFALSE(tidy_args$exponentiate)) {
       tidy_args$exponentiate <- NULL
     } else {
@@ -161,6 +176,13 @@ tidy_with_broom_or_parameters <- function(x, conf.int = TRUE, conf.level = .95,
     tidy_args$conf.int <- NULL
   }
 
+  # specific case for quantreg::rq models
+  # exponentiate and conf.int not supported by broom::tidy()
+  if (inherits(x, "rq") || inherits(x, "rqs")) {
+    tidy_args$exponentiate <- NULL
+    tidy_args$conf.int <- NULL
+  }
+
   # for betareg, if exponentiate = TRUE, forcing tidy_parameters,
   # by adding `component = "all" to the arguments`
   if (inherits(x, "betareg")) {
@@ -256,6 +278,16 @@ tidy_with_broom_or_parameters <- function(x, conf.int = TRUE, conf.level = .95,
     res <- .exponentiate(res)
   }
 
+  # specific case for quantreg::rq models
+  if (
+    "tau" %in% names(res) &&
+      !"component" %in% names(res) &&
+      length(unique(res$tau)) > 1
+  ) {
+    res <- res |>
+      dplyr::mutate(component = .data$tau)
+  }
+
   res
 }
 
@@ -264,7 +296,7 @@ tidy_with_broom_or_parameters <- function(x, conf.int = TRUE, conf.level = .95,
 #' @param x (a model object, e.g. `glm`)\cr
 #' A model to be tidied.
 #' @param ... Additional parameters passed to `broom::tidy()`.
-#' @family custom_tieders
+#' @family custom_tidiers
 #' @export
 tidy_broom <- function(x, ...) {
   rlang::check_dots_used()
@@ -288,7 +320,7 @@ tidy_broom <- function(x, ...) {
 #' latest modality of `y`.
 #'
 #' @export
-#' @family custom_tieders
+#' @family custom_tidiers
 #' @examplesIf .assert_package("multgee", boolean = TRUE)
 #' \donttest{
 #'   library(multgee)
@@ -367,7 +399,7 @@ tidy_multgee <- function(x, conf.int = TRUE, conf.level = .95, ...) {
 #' `NULL` or one of `"all"`, `"conditional"`, `"zi"`, or `"zero_inflated"`.
 #' @param ... Additional parameters passed to `parameters::model_parameters()`.
 #' @export
-#' @family custom_tieders
+#' @family custom_tidiers
 #' @examplesIf .assert_package("pscl", boolean = TRUE)
 #' \donttest{
 #'   library(pscl)
@@ -428,7 +460,7 @@ tidy_zeroinfl <- function(
 #' The confidence level to use for the confidence interval (between `0` ans `1`).
 #' @param ... Additional parameters passed to `parameters::model_parameters()`.
 #' @export
-#' @family custom_tieders
+#' @family custom_tidiers
 #' @examplesIf .assert_package("VGAM", boolean = TRUE)
 #' \donttest{
 #'   library(VGAM)
@@ -460,7 +492,12 @@ tidy_vgam <- function(
     conf.level = conf.level,
     ...
   )
-  res <- res |> dplyr::rename(original_term = .data$term)
+
+  .process_vgam_tidy_tbl(res, x)
+}
+
+.process_vgam_tidy_tbl <- function(res, x) {
+  res <- res |> dplyr::rename(original_term = dplyr::all_of("term"))
 
   # identify groups
   res <- res |>
@@ -496,7 +533,7 @@ tidy_vgam <- function(
 
   # remove component if all empty
   if (all(res$component == ""))
-    res <- res |> dplyr::select(-.data$component, -.data$group)
+    res <- res |> dplyr::select(-dplyr::all_of(c("component", "group")))
 
   res
 }
@@ -524,3 +561,50 @@ tidy_vgam <- function(
     )
   t
 }
+
+#' Tidy a `svy_vglm` model
+#'
+#' `r lifecycle::badge("experimental")`
+#' A tidier for models generated with `svyVGAM::svy_vglm()`.
+#' Term names will be updated to be consistent with generic models. The original
+#' term names are preserved in an `"original_term"` column. Depending on the
+#' model, additional column `"group"`, `"component"` and/or `"y.level"` may be
+#' added to the results.
+#' @param x (`svy_vglm`)\cr
+#' A `svyVGAM::svy_vglm()` model.
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters passed to `parameters::model_parameters()`.
+#' @export
+#' @family custom_tidiers
+#' @examplesIf .assert_package("svyVGAM", boolean = TRUE)
+#' \donttest{
+#'   library(svyVGAM)
+#'
+#'   mod <- svy_vglm(
+#'     Species ~ Sepal.Length + Sepal.Width,
+#'     family = multinomial(),
+#'     design = survey::svydesign(~1, data = iris)
+#'   )
+#'   mod |> tidy_svy_vglm(exponentiate = TRUE)
+#' }
+tidy_svy_vglm <- function(
+    x,
+    conf.int = TRUE,
+    conf.level = .95,
+    ...) {
+  if (!inherits(x, "svy_vglm")) {
+    cli::cli_abort("{.arg x} should be of class {.cls svy_vglm}.")
+  } # nolint
+
+  res <- tidy_parameters(
+    x,
+    conf.int = conf.int,
+    conf.level = conf.level,
+    ...
+  )
+
+  .process_vgam_tidy_tbl(res, x$fit)
+}
