@@ -1,6 +1,14 @@
 #' Average Marginal Effects with `margins::margins()`
 #'
-#' `r lifecycle::badge("experimental")`
+#' `r lifecycle::badge("superseded")`
+#'
+#' The `margins` package is no longer under active development and may be
+#' removed from CRAN sooner or later. It is advised to use the `marginaleffects`
+#' package instead, offering more functionalities. You could have a look at the
+#' [article](https://larmarange.github.io/broom.helpers/articles/marginal_tidiers.html)
+#' dedicated to marginal estimates with `broom.helpers`. `tidy_avg_slopes()`
+#' could be used as an alternative.
+#'
 #' Use `margins::margins()` to estimate average marginal effects (AME) and
 #' return a tibble tidied in a way that it could be used by `broom.helpers`
 #' functions. See `margins::margins()` for a list of supported models.
@@ -13,18 +21,21 @@
 #' @note When applying `margins::margins()`, custom contrasts are ignored.
 #' Treatment contrasts (`stats::contr.treatment()`) are applied to all
 #' categorical variables. Interactions are also ignored.
-#' @param x a model
-#' @param conf.int logical indicating whether or not to include a confidence
-#' interval in the tidied output
-#' @param conf.level the confidence level to use for the confidence interval
-#' @param ... additional parameters passed to `margins::margins()`
+#' @param x (a model object, e.g. `glm`)\cr
+#' A model to be tidied.
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters passed to `margins::margins()`.
 #' @family marginal_tieders
 #' @seealso `margins::margins()`
 #' @export
-#' @examplesIf interactive()
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   tidyr::uncount(n) %>%
+#' @examplesIf .assert_package("margins", boolean = TRUE)
+#' \donttest{
+#' df <- Titanic |>
+#'   dplyr::as_tibble() |>
+#'   tidyr::uncount(n) |>
 #'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes")))
 #' mod <- glm(
 #'   Survived ~ Class + Age + Sex,
@@ -32,6 +43,7 @@
 #' )
 #' tidy_margins(mod)
 #' tidy_plus_plus(mod, tidy_fun = tidy_margins)
+#' }
 tidy_margins <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
   .assert_package("margins")
 
@@ -52,7 +64,6 @@ tidy_margins <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 
 #' Marginal Predictions at the mean with `effects::allEffects()`
 #'
-#' `r lifecycle::badge("experimental")`
 #' Use `effects::allEffects()` to estimate marginal predictions and
 #' return a tibble tidied in a way that it could be used by `broom.helpers`
 #' functions.
@@ -70,18 +81,21 @@ tidy_margins <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #' @note
 #' If the model contains interactions, `effects::allEffects()` will return
 #' marginal predictions for the different levels of the interactions.
-#' @param x a model
-#' @param conf.int logical indicating whether or not to include a confidence
-#' interval in the tidied output
-#' @param conf.level the confidence level to use for the confidence interval
-#' @param ... additional parameters passed to `effects::allEffects()`
+#' @param x (a model object, e.g. `glm`)\cr
+#' A model to be tidied.
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters passed to `effects::allEffects()`.
 #' @family marginal_tieders
 #' @seealso `effects::allEffects()`
 #' @export
-#' @examplesIf interactive()
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   tidyr::uncount(n) %>%
+#' @examplesIf .assert_package("effects", boolean = TRUE)
+#' \donttest{
+#' df <- Titanic |>
+#'   dplyr::as_tibble() |>
+#'   tidyr::uncount(n) |>
 #'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes")))
 #' mod <- glm(
 #'   Survived ~ Class + Age + Sex,
@@ -89,6 +103,7 @@ tidy_margins <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #' )
 #' tidy_all_effects(mod)
 #' tidy_plus_plus(mod, tidy_fun = tidy_all_effects)
+#' }
 tidy_all_effects <- function(x, conf.int = TRUE, conf.level = .95, ...) {
   .assert_package("effects")
 
@@ -112,11 +127,11 @@ tidy_all_effects <- function(x, conf.int = TRUE, conf.level = .95, ...) {
     rownames(x) <- NULL
     x
   }
-  res <- x %>%
-    effects::allEffects(se = conf.int, level = conf.level, ...) %>%
-    as.data.frame() %>%
-    purrr::map(.clean) %>%
-    dplyr::bind_rows(.id = "variable") %>%
+  res <- x |>
+    effects::allEffects(se = conf.int, level = conf.level, ...) |>
+    as.data.frame() |>
+    purrr::map(.clean) |>
+    dplyr::bind_rows(.id = "variable") |>
     dplyr::relocate("variable", "term")
   attr(res, "coefficients_type") <- "marginal_predictions_at_mean"
   attr(res, "skip_add_reference_rows") <- TRUE
@@ -125,10 +140,10 @@ tidy_all_effects <- function(x, conf.int = TRUE, conf.level = .95, ...) {
 }
 
 tidy_all_effects_effpoly <- function(x, conf.int = TRUE, conf.level = .95, ...) {
-  res <- x %>%
-    effects::allEffects(se = conf.int, level = conf.level, ...) %>%
-    purrr::map(effpoly_to_df) %>%
-    dplyr::bind_rows(.id = "variable") %>%
+  res <- x |>
+    effects::allEffects(se = conf.int, level = conf.level, ...) |>
+    purrr::map(effpoly_to_df) |>
+    dplyr::bind_rows(.id = "variable") |>
     dplyr::relocate("y.level", "variable", "term")
   attr(res, "coefficients_type") <- "marginal_predictions_at_mean"
   attr(res, "skip_add_reference_rows") <- TRUE
@@ -151,9 +166,9 @@ effpoly_to_df <- function(x) {
 
   result <- rep.int(list(x$x), length(x$y.levels))
   names(result) <- x$y.levels
-  result <- result %>% dplyr::bind_rows(.id = "y.level")
+  result <- result |> dplyr::bind_rows(.id = "y.level")
   # merge columns if interaction
-  result <- result %>% tidyr::unite("term", 2:ncol(result), sep = ":")
+  result <- result |> tidyr::unite("term", 2:ncol(result), sep = ":")
   result$estimate <- as.vector(x$prob)
   result$std.error <- as.vector(x$se.prob)
 
@@ -166,7 +181,6 @@ effpoly_to_df <- function(x) {
 
 #' Marginal Predictions with `ggeffects::ggpredict()`
 #'
-#' `r lifecycle::badge("experimental")`
 #' Use `ggeffects::ggpredict()` to estimate marginal predictions
 #' and return a tibble tidied in a way that it could be used by `broom.helpers`
 #' functions.
@@ -181,18 +195,21 @@ effpoly_to_df <- function(x) {
 #' @note
 #' By default, `ggeffects::ggpredict()` estimates marginal predictions for each
 #' individual variable, regardless of eventual interactions.
-#' @param x a model
-#' @param conf.int logical indicating whether or not to include a confidence
-#' interval in the tidied output
-#' @param conf.level the confidence level to use for the confidence interval
-#' @param ... additional parameters passed to `ggeffects::ggpredict()`
+#' @param x (a model object, e.g. `glm`)\cr
+#' A model to be tidied.
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters passed to `ggeffects::ggpredict()`.
 #' @family marginal_tieders
 #' @seealso `ggeffects::ggpredict()`
 #' @export
-#' @examplesIf interactive()
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   tidyr::uncount(n) %>%
+#' @examplesIf .assert_package("ggeffects", boolean = TRUE)
+#' \donttest{
+#' df <- Titanic |>
+#'   dplyr::as_tibble() |>
+#'   tidyr::uncount(n) |>
 #'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes")))
 #' mod <- glm(
 #'   Survived ~ Class + Age + Sex,
@@ -200,6 +217,7 @@ effpoly_to_df <- function(x) {
 #' )
 #' tidy_ggpredict(mod)
 #' tidy_plus_plus(mod, tidy_fun = tidy_ggpredict)
+#' }
 tidy_ggpredict <- function(x, conf.int = TRUE, conf.level = .95, ...) {
   .assert_package("ggeffects")
 
@@ -209,24 +227,24 @@ tidy_ggpredict <- function(x, conf.int = TRUE, conf.level = .95, ...) {
   }
 
   if (isFALSE(conf.int)) conf.level <- NA
-  res <- x %>%
-    ggeffects::ggpredict(ci.lvl = conf.level) %>% # add ...
+  res <- x |>
+    ggeffects::ggpredict(ci_level = conf.level) |> # add ...
     purrr::map(
-      ~ .x %>%
-        dplyr::as_tibble() %>%
+      ~ .x |>
+        dplyr::as_tibble() |>
         dplyr::mutate(x = as.character(.data$x))
-    ) %>%
-    dplyr::bind_rows() %>%
+    ) |>
+    dplyr::bind_rows() |>
     dplyr::rename(
       variable = "group",
       term = "x",
       estimate = "predicted"
-    ) %>%
+    ) |>
     dplyr::relocate("variable", "term")
   # multinomial models
   if ("response.level" %in% names(res)) {
-    res <- res %>%
-      dplyr::rename(y.level = "response.level") %>%
+    res <- res |>
+      dplyr::rename(y.level = "response.level") |>
       dplyr::relocate("y.level")
   }
   attr(res, "coefficients_type") <- "marginal_predictions"
@@ -236,7 +254,6 @@ tidy_ggpredict <- function(x, conf.int = TRUE, conf.level = .95, ...) {
 
 #' Marginal Slopes / Effects with `marginaleffects::avg_slopes()`
 #'
-#' `r lifecycle::badge("experimental")`
 #' Use `marginaleffects::avg_slopes()` to estimate marginal slopes / effects and
 #' return a tibble tidied in a way that it could be used by `broom.helpers`
 #' functions. See `marginaleffects::avg_slopes()` for a list of supported
@@ -250,21 +267,24 @@ tidy_ggpredict <- function(x, conf.int = TRUE, conf.level = .95, ...) {
 #' `marginaleffects::avg_slopes()`.
 #'
 #' For more information, see `vignette("marginal_tidiers", "broom.helpers")`.
-#' @param x a model
-#' @param conf.int logical indicating whether or not to include a confidence
-#' interval in the tidied output
-#' @param conf.level the confidence level to use for the confidence interval
-#' @param ... additional parameters passed to
-#' `marginaleffects::avg_slopes()`
+#' @param x (a model object, e.g. `glm`)\cr
+#' A model to be tidied.
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters passed to
+#' `marginaleffects::avg_slopes()`.
 #' @family marginal_tieders
 #' @seealso `marginaleffects::avg_slopes()`
 #' @export
-#' @examplesIf interactive()
+#' @examplesIf .assert_package("marginaleffects", boolean = TRUE)
+#' \donttest{
 #' # Average Marginal Effects (AME)
 #'
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   tidyr::uncount(n) %>%
+#' df <- Titanic |>
+#'   dplyr::as_tibble() |>
+#'   tidyr::uncount(n) |>
 #'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes")))
 #' mod <- glm(
 #'   Survived ~ Class + Age + Sex,
@@ -279,6 +299,7 @@ tidy_ggpredict <- function(x, conf.int = TRUE, conf.level = .95, ...) {
 #' # Marginal Effects at the Mean (MEM)
 #' tidy_avg_slopes(mod, newdata = "mean")
 #' tidy_plus_plus(mod, tidy_fun = tidy_avg_slopes, newdata = "mean")
+#' }
 tidy_avg_slopes <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
   .assert_package("marginaleffects")
 
@@ -290,37 +311,36 @@ tidy_avg_slopes <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
   dots$conf_level <- conf.level
   dots$model <- x
 
-  res <- do.call(marginaleffects::avg_slopes, dots) %>%
+  res <- do.call(marginaleffects::avg_slopes, dots) |>
     dplyr::rename(variable = "term")
   if ("contrast" %in% names(res)) {
-    res <- res %>% dplyr::rename(term = "contrast")
+    res <- res |> dplyr::rename(term = "contrast")
   } else {
-    res <- res %>% dplyr::mutate(term = .data$variable)
+    res <- res |> dplyr::mutate(term = .data$variable)
   }
 
-  res <- res %>%
+  res <- res |>
     dplyr::relocate("variable", "term")
 
   # multinomial models
   if ("group" %in% names(res)) {
-    res <- res %>%
-      dplyr::rename(y.level = "group") %>%
+    res <- res |>
+      dplyr::rename(y.level = "group") |>
       dplyr::relocate("y.level")
   }
 
   attr(res, "coefficients_type") <- dplyr::case_when(
     is.null(dots$newdata) ~ "marginal_effects_average",
     isTRUE(dots$newdata == "mean") ~ "marginal_effects_at_mean",
-    isTRUE(dots$newdata == "marginalmeans") ~ "marginal_effects_at_marginalmeans",
+    isTRUE(dots$newdata == "balanced") ~ "marginal_effects_at_marginalmeans",
     TRUE ~ "marginal_effects"
   )
   attr(res, "skip_add_reference_rows") <- TRUE
-  res %>% dplyr::as_tibble()
+  res |> dplyr::as_tibble()
 }
 
 #' Marginal Contrasts with `marginaleffects::avg_comparisons()`
 #'
-#' `r lifecycle::badge("experimental")`
 #' Use `marginaleffects::avg_comparisons()` to estimate marginal contrasts and
 #' return a tibble tidied in a way that it could be used by `broom.helpers`
 #' functions. See `marginaleffects::avg_comparisons()` for a list of supported
@@ -336,21 +356,24 @@ tidy_avg_slopes <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #'
 #' See also `tidy_marginal_contrasts()` for taking into account interactions.
 #' For more information, see `vignette("marginal_tidiers", "broom.helpers")`.
-#' @param x a model
-#' @param conf.int logical indicating whether or not to include a confidence
-#' interval in the tidied output
-#' @param conf.level the confidence level to use for the confidence interval
-#' @param ... additional parameters passed to
-#' `marginaleffects::avg_comparisons()`
+#' @param x (a model object, e.g. `glm`)\cr
+#' A model to be tidied.
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters passed to
+#' `marginaleffects::avg_comparisons()`.
 #' @family marginal_tieders
 #' @seealso `marginaleffects::avg_comparisons()`
 #' @export
-#' @examplesIf interactive()
+#' @examplesIf .assert_package("marginaleffects", boolean = TRUE)
+#' \donttest{
 #' # Average Marginal Contrasts
 #'
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   tidyr::uncount(n) %>%
+#' df <- Titanic |>
+#'   dplyr::as_tibble() |>
+#'   tidyr::uncount(n) |>
 #'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes")))
 #' mod <- glm(
 #'   Survived ~ Class + Age + Sex,
@@ -371,6 +394,7 @@ tidy_avg_slopes <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #' # Marginal Contrasts at the Mean
 #' tidy_avg_comparisons(mod, newdata = "mean")
 #' tidy_plus_plus(mod, tidy_fun = tidy_avg_comparisons, newdata = "mean")
+#' }
 tidy_avg_comparisons <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
   .assert_package("marginaleffects")
 
@@ -382,107 +406,59 @@ tidy_avg_comparisons <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
   dots$conf_level <- conf.level
   dots$model <- x
 
-  res <- do.call(marginaleffects::avg_comparisons, dots) %>%
+  res <- do.call(marginaleffects::avg_comparisons, dots) |>
     dplyr::rename(variable = "term")
   if ("contrast" %in% names(res)) {
-    res <- res %>% dplyr::rename(term = "contrast")
+    res <- res |> dplyr::rename(term = "contrast")
   } else {
-    res <- res %>% dplyr::mutate(term = .data$variable)
+    res <- res |> dplyr::mutate(term = .data$variable)
   }
 
-  res <- res %>%
+  res <- res |>
     dplyr::relocate("variable", "term")
 
   # multinomial models
   if ("group" %in% names(res)) {
-    res <- res %>%
-      dplyr::rename(y.level = "group") %>%
+    res <- res |>
+      dplyr::rename(y.level = "group") |>
       dplyr::relocate("y.level")
   }
 
   attr(res, "coefficients_type") <- dplyr::case_when(
     is.null(dots$newdata) ~ "marginal_contrasts_average",
     isTRUE(dots$newdata == "mean") ~ "marginal_contrasts_at_mean",
-    isTRUE(dots$newdata == "marginalmeans") ~ "marginal_contrasts_at_marginalmeans",
+    isTRUE(dots$newdata == "balanced") ~ "marginal_contrasts_at_marginalmeans",
     TRUE ~ "marginal_contrasts"
   )
   attr(res, "skip_add_reference_rows") <- TRUE
-  res %>% dplyr::as_tibble()
+  res |> dplyr::as_tibble()
 }
 
-#' Marginal Means with `marginaleffects::marginal_means()`
+#' Marginal Means with deprecated `marginaleffects::marginal_means()`
 #'
-#' `r lifecycle::badge("experimental")`
-#' Use `marginaleffects::marginal_means()` to estimate marginal means and
-#' return a tibble tidied in a way that it could be used by `broom.helpers`
-#' functions. See `marginaleffects::marginal_means()()` for a list of supported
-#' models.
-#' @details
-#' `marginaleffects::marginal_means()` estimate marginal means:
-#' adjusted predictions, averaged across a grid of categorical predictors,
-#' holding other numeric predictors at their means. Please refer to the
-#' documentation page of `marginaleffects::marginal_means()`. Marginal means
-#' are defined only for categorical variables.
-#'
-#' For more information, see `vignette("marginal_tidiers", "broom.helpers")`.
-#' @param x a model
-#' @param conf.int logical indicating whether or not to include a confidence
-#' interval in the tidied output
-#' @param conf.level the confidence level to use for the confidence interval
-#' @param ... additional parameters passed to
-#' `marginaleffects::marginal_means()`
-#' @family marginal_tieders
-#' @seealso `marginaleffects::marginal_means()`
+#' `r lifecycle::badge("deprecated")`
+#' This function is deprecated. `marginal_means()` is not anymore exported
+#' by `marginaleffects`. Use instead `tidy_marginal_predictions()` with
+#' the option `newdata = "balanced"`.
+#' @param x (a model object, e.g. `glm`)\cr
+#' A model to be tidied.
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters.
 #' @export
-#' @examplesIf interactive()
-#' # Average Marginal Means
-#'
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   tidyr::uncount(n) %>%
-#'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes")))
-#' mod <- glm(
-#'   Survived ~ Class + Age + Sex,
-#'   data = df, family = binomial
-#' )
-#' tidy_marginal_means(mod)
-#' tidy_plus_plus(mod, tidy_fun = tidy_marginal_means)
-#'
-#' mod2 <- lm(Petal.Length ~ poly(Petal.Width, 2) + Species, data = iris)
-#' tidy_marginal_means(mod2)
 tidy_marginal_means <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
-  .assert_package("marginaleffects")
-
-  dots <- rlang::dots_list(...)
-  if (isTRUE(dots$exponentiate)) {
-    cli::cli_abort("{.arg exponentiate = TRUE} is not relevant for {.fun broom.helpers::tidy_marginal_means}.") # nolint
-  }
-  dots$exponentiate <- NULL
-  dots$conf_level <- conf.level
-  dots$model <- x
-
-  res <- do.call(marginaleffects::marginal_means, dots) %>%
-    dplyr::rename(
-      variable = "term",
-      term = "value"
-    ) %>%
-    dplyr::mutate(term = as.character(.data$term))
-
-  # multinomial models
-  if ("group" %in% names(res)) {
-    res <- res %>%
-      dplyr::rename(y.level = "group") %>%
-      dplyr::relocate("y.level")
-  }
-
-  attr(res, "coefficients_type") <- "marginal_means"
-  attr(res, "skip_add_reference_rows") <- TRUE
-  res %>% dplyr::as_tibble()
+  lifecycle::deprecate_stop(
+    when = "1.19.0",
+    what = "tidy_marginal_means()",
+    with = "tidy_marginal_predictions()",
+    details = "Specify `newdata = \"balanced\"`."
+  )
 }
 
 #' Marginal Predictions with `marginaleffects::avg_predictions()`
 #'
-#' `r lifecycle::badge("experimental")`
 #' Use `marginaleffects::avg_predictions()` to estimate marginal predictions for
 #' each variable of a model and return a tibble tidied in a way that it could
 #' be used by `broom.helpers` functions.
@@ -533,24 +509,30 @@ tidy_marginal_means <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #' plots that could be combined with `patchwork::wrap_plots()` (see examples).
 #'
 #' For more information, see `vignette("marginal_tidiers", "broom.helpers")`.
-#' @param x a model
-#' @param variables_list a list whose elements will be sequentially passed to
+#' @param x (a model object, e.g. `glm`)\cr
+#' A model to be tidied.
+#' @param variables_list (`list` or `string`)\cr
+#' A list whose elements will be sequentially passed to
 #' `variables` in `marginaleffects::avg_predictions()` (see details below);
 #' alternatively, it could also be the string `"auto"` (default) or
-#' `"no_interaction"`
-#' @param conf.int logical indicating whether or not to include a confidence
-#' interval in the tidied output
-#' @param conf.level the confidence level to use for the confidence interval
-#' @param ... additional parameters passed to
-#' `marginaleffects::avg_predictions()`
+#' `"no_interaction"`.
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters passed to
+#' `marginaleffects::avg_predictions()`.
 #' @family marginal_tieders
 #' @seealso `marginaleffects::avg_predictions()`
 #' @export
-#' @examplesIf interactive()
+#' @examplesIf .assert_package("marginaleffects", boolean = TRUE)
+#' # example code
+#'
+#' \donttest{
 #' # Average Marginal Predictions
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   tidyr::uncount(n) %>%
+#' df <- Titanic |>
+#'   dplyr::as_tibble() |>
+#'   tidyr::uncount(n) |>
 #'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes")))
 #' mod <- glm(
 #'   Survived ~ Class + Age + Sex,
@@ -559,8 +541,8 @@ tidy_marginal_means <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #' tidy_marginal_predictions(mod)
 #' tidy_plus_plus(mod, tidy_fun = tidy_marginal_predictions)
 #' if (require("patchwork")) {
-#'   plot_marginal_predictions(mod) %>% patchwork::wrap_plots()
-#'   plot_marginal_predictions(mod) %>%
+#'   plot_marginal_predictions(mod) |> patchwork::wrap_plots()
+#'   plot_marginal_predictions(mod) |>
 #'     patchwork::wrap_plots() &
 #'     ggplot2::scale_y_continuous(limits = c(0, 1), label = scales::percent)
 #' }
@@ -568,7 +550,7 @@ tidy_marginal_means <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #' mod2 <- lm(Petal.Length ~ poly(Petal.Width, 2) + Species, data = iris)
 #' tidy_marginal_predictions(mod2)
 #' if (require("patchwork")) {
-#'   plot_marginal_predictions(mod2) %>% patchwork::wrap_plots()
+#'   plot_marginal_predictions(mod2) |> patchwork::wrap_plots()
 #' }
 #' tidy_marginal_predictions(
 #'   mod2,
@@ -594,9 +576,9 @@ tidy_marginal_means <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #' tidy_marginal_predictions(mod3)
 #' tidy_marginal_predictions(mod3, "no_interaction")
 #' if (require("patchwork")) {
-#'   plot_marginal_predictions(mod3) %>%
+#'   plot_marginal_predictions(mod3) |>
 #'     patchwork::wrap_plots()
-#'   plot_marginal_predictions(mod3, "no_interaction") %>%
+#'   plot_marginal_predictions(mod3, "no_interaction") |>
 #'     patchwork::wrap_plots()
 #' }
 #' tidy_marginal_predictions(
@@ -610,9 +592,10 @@ tidy_marginal_means <- function(x, conf.int = TRUE, conf.level = 0.95, ...) {
 #' # Marginal Predictions at the Mean
 #' tidy_marginal_predictions(mod, newdata = "mean")
 #' if (require("patchwork")) {
-#'   plot_marginal_predictions(mod, newdata = "mean") %>%
+#'   plot_marginal_predictions(mod, newdata = "mean") |>
 #'     patchwork::wrap_plots()
 #' }
+#' }
 tidy_marginal_predictions <- function(x, variables_list = "auto",
                                       conf.int = TRUE, conf.level = 0.95, ...) {
   .assert_package("marginaleffects")
@@ -640,7 +623,7 @@ tidy_marginal_predictions <- function(x, variables_list = "auto",
   attr(res, "coefficients_type") <- dplyr::case_when(
     is.null(dots$newdata) ~ "marginal_predictions_average",
     isTRUE(dots$newdata == "mean") ~ "marginal_predictions_at_mean",
-    isTRUE(dots$newdata == "marginalmeans") ~ "marginal_predictions_at_marginalmeans",
+    isTRUE(dots$newdata == "balanced") ~ "marginal_predictions_at_marginalmeans",
     TRUE ~ "marginal_predictions"
   )
   attr(res, "skip_add_reference_rows") <- TRUE
@@ -658,14 +641,15 @@ tidy_marginal_predictions <- function(x, variables_list = "auto",
     dots$by <- c(dots$by, "group")
   }
 
-  res <- do.call(marginaleffects::avg_predictions, dots) %>%
-    dplyr::mutate(variable = paste(names(variables), collapse = ":")) %>%
-    tidyr::unite(col = "term", sep = " * ", dplyr::all_of(names(variables))) %>%
+  res <- do.call(marginaleffects::avg_predictions, dots) |>
+    dplyr::arrange(dplyr::pick(dplyr::any_of(c(names(variables)))), "group") |>
+    dplyr::mutate(variable = paste(names(variables), collapse = ":")) |>
+    tidyr::unite(col = "term", sep = " * ", dplyr::all_of(names(variables))) |>
     dplyr::relocate("variable", "term")
 
   if ("group" %in% names(res)) {
-    res <- res %>%
-      dplyr::rename(y.level = "group") %>%
+    res <- res |>
+      dplyr::rename(y.level = "group") |>
       dplyr::relocate("y.level")
   }
 
@@ -673,16 +657,20 @@ tidy_marginal_predictions <- function(x, variables_list = "auto",
 }
 
 #' @export
-#' @param model a model
-#' @param interactions should combinations of variables corresponding to
+#' @param model (a model object, e.g. `glm`)\cr
+#' A model.
+#' @param interactions (`logical`)\cr
+#' Should combinations of variables corresponding to
 #' interactions be returned?
-#' @param categorical default value for categorical variables
-#' @param continuous default value for continuous variables
+#' @param categorical ([`predictor values`][marginaleffects::predictions()])\cr
+#' Default values for categorical variables.
+#' @param continuous ([`predictor values`][marginaleffects::predictions()])\cr
+#' Default values for continuous variables.
 #' @rdname tidy_marginal_predictions
 variables_to_predict <- function(model, interactions = TRUE,
                                  categorical = unique,
                                  continuous = stats::fivenum) {
-  variables <- model %>%
+  variables <- model |>
     model_list_variables(add_var_type = TRUE)
 
   if (interactions) {
@@ -691,7 +679,7 @@ variables_to_predict <- function(model, interactions = TRUE,
     keep <- variables[variables$var_type != "interaction", ]$variable
   }
 
-  response_variable <- model %>% model_get_response_variable()
+  response_variable <- model |> model_get_response_variable()
   if (!is.null(response_variable)) {
     keep <- keep[keep != response_variable]
   }
@@ -701,11 +689,11 @@ variables_to_predict <- function(model, interactions = TRUE,
     dichotomous = categorical,
     continuous = continuous
   )
-  variables <- variables %>%
+  variables <- variables |>
     tibble::column_to_rownames("variable")
 
   one_element <- function(v) {
-    v <- strsplit(v, ":") %>% unlist()
+    v <- strsplit(v, ":") |> unlist()
     one <- variables[v, "var_type"]
     one <- ret[one]
     names(one) <- v
@@ -726,11 +714,11 @@ plot_marginal_predictions <- function(x, variables_list = "auto",
   dots$model <- x
 
   if (is.character(variables_list) && variables_list == "auto") {
-    variables_list <- variables_to_predict(x, interactions = TRUE) %>%
+    variables_list <- variables_to_predict(x, interactions = TRUE) |>
       purrr::map(rev)
   }
   if (is.character(variables_list) && variables_list == "no_interaction") {
-    variables_list <- variables_to_predict(x, interactions = FALSE) %>%
+    variables_list <- variables_to_predict(x, interactions = FALSE) |>
       purrr::map(rev)
   }
   if (!is.list(variables_list)) {
@@ -751,14 +739,14 @@ plot_marginal_predictions <- function(x, variables_list = "auto",
   multinom <- inherits(dots$model, "multinom") | inherits(dots$model, "polr") |
     inherits(dots$model, "clm") | inherits(dots$model, "clmm")
 
-  list_variables <- dots$model %>% model_list_variables(add_var_type = TRUE)
+  list_variables <- dots$model |> model_list_variables(add_var_type = TRUE)
   x_variable <- names(variables[1])
-  x_type <- list_variables %>%
-    dplyr::filter(.data$variable == x_variable) %>%
+  x_type <- list_variables |>
+    dplyr::filter(.data$variable == x_variable) |>
     dplyr::pull("var_type")
   if (x_type == "dichotomous") x_type <- "categorical"
-  x_label <- list_variables %>%
-    dplyr::filter(.data$variable == x_variable) %>%
+  x_label <- list_variables |>
+    dplyr::filter(.data$variable == x_variable) |>
     dplyr::pull("var_label")
 
   if (is.character(variables[[1]]) && variables[[1]] == "fivenum") {
@@ -785,8 +773,8 @@ plot_marginal_predictions <- function(x, variables_list = "auto",
   if (length(variables) >= 2) {
     colour_variable <- names(variables[2])
     d[[colour_variable]] <- factor(d[[colour_variable]])
-    colour_label <- list_variables %>%
-      dplyr::filter(.data$variable == colour_variable) %>%
+    colour_label <- list_variables |>
+      dplyr::filter(.data$variable == colour_variable) |>
       dplyr::pull("var_label")
     mapping$colour <- ggplot2::aes(colour = .data[[colour_variable]])$colour
     if (x_type == "continuous") {
@@ -839,7 +827,6 @@ plot_marginal_predictions <- function(x, variables_list = "auto",
 
 #' Marginal Contrasts with `marginaleffects::avg_comparisons()`
 #'
-#' `r lifecycle::badge("experimental")`
 #' Use `marginaleffects::avg_comparisons()` to estimate marginal contrasts for
 #' each variable of a model and return a tibble tidied in a way that it could
 #' be used by `broom.helpers` functions.
@@ -891,24 +878,28 @@ plot_marginal_predictions <- function(x, variables_list = "auto",
 #' see the help file of `marginaleffects::avg_comparisons()`.
 #'
 #' For more information, see `vignette("marginal_tidiers", "broom.helpers")`.
-#' @param x a model
-#' @param variables_list a list whose elements will be sequentially passed to
+#' @param x (a model object, e.g. `glm`)\cr
+#' A model to be tidied.
+#' @param variables_list (`list` or `string`)\cr
+#' A list whose elements will be sequentially passed to
 #' `variables` in `marginaleffects::avg_comparisons()` (see details below);
 #' alternatively, it could also be the string `"auto"` (default), `"cross"` or
 #' `"no_interaction"`
-#' @param conf.int logical indicating whether or not to include a confidence
-#' interval in the tidied output
-#' @param conf.level the confidence level to use for the confidence interval
-#' @param ... additional parameters passed to
-#' `marginaleffects::avg_comparisons()`
+#' @param conf.int (`logical`)\cr
+#' Whether or not to include a confidence interval in the tidied output.
+#' @param conf.level (`numeric`)\cr
+#' The confidence level to use for the confidence interval (between `0` ans `1`).
+#' @param ... Additional parameters passed to
+#' `marginaleffects::avg_comparisons()`.
 #' @family marginal_tieders
 #' @seealso `marginaleffects::avg_comparisons()`, `tidy_avg_comparisons()`
 #' @export
-#' @examplesIf interactive()
+#' @examplesIf .assert_package("marginaleffects", boolean = TRUE)
+#' \donttest{
 #' # Average Marginal Contrasts
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   tidyr::uncount(n) %>%
+#' df <- Titanic |>
+#'   dplyr::as_tibble() |>
+#'   tidyr::uncount(n) |>
 #'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes")))
 #' mod <- glm(
 #'   Survived ~ Class + Age + Sex,
@@ -964,6 +955,7 @@ plot_marginal_predictions <- function(x, variables_list = "auto",
 #' # Marginal Contrasts at the Mean
 #' tidy_marginal_contrasts(mod, newdata = "mean")
 #' tidy_marginal_contrasts(mod3, newdata = "mean")
+#' }
 tidy_marginal_contrasts <- function(x, variables_list = "auto",
                                     conf.int = TRUE, conf.level = 0.95, ...) {
   .assert_package("marginaleffects")
@@ -1005,7 +997,7 @@ tidy_marginal_contrasts <- function(x, variables_list = "auto",
   attr(res, "coefficients_type") <- dplyr::case_when(
     is.null(dots$newdata) ~ "marginal_contrasts_average",
     isTRUE(dots$newdata == "mean") ~ "marginal_contrasts_at_mean",
-    isTRUE(dots$newdata == "marginalmeans") ~ "marginal_contrasts_at_marginalmeans",
+    isTRUE(dots$newdata == "balanced") ~ "marginal_contrasts_at_marginalmeans",
     TRUE ~ "marginal_contrasts"
   )
   attr(res, "skip_add_reference_rows") <- TRUE
@@ -1028,7 +1020,8 @@ tidy_marginal_contrasts <- function(x, variables_list = "auto",
   if (!is.null(variables$by) && is.null(dots$newdata)) {
     args <- variables$by
     args$model <- dots$model
-    dots$newdata <- do.call(marginaleffects::datagridcf, args)
+    args$grid_type <- "counterfactual"
+    dots$newdata <- do.call(marginaleffects::datagrid, args)
   }
 
   if (!is.null(variables$by) && identical(dots$newdata, "mean")) {
@@ -1037,15 +1030,15 @@ tidy_marginal_contrasts <- function(x, variables_list = "auto",
     dots$newdata <- do.call(marginaleffects::datagrid, args)
   }
 
-  res <- do.call(marginaleffects::avg_comparisons, dots) %>%
+  res <- do.call(marginaleffects::avg_comparisons, dots) |>
     dplyr::select(-dplyr::any_of("term"))
   if (is.null(variables$by)) {
-    res <- res %>%
+    res <- res |>
       dplyr::mutate(
         variable = paste(names(variables$variables), collapse = ":")
       )
   } else {
-    res <- res %>%
+    res <- res |>
       dplyr::mutate(
         variable = paste(
           paste(names(variables$by), collapse = ":"),
@@ -1055,18 +1048,18 @@ tidy_marginal_contrasts <- function(x, variables_list = "auto",
       )
   }
 
-  res <- res %>%
+  res <- res |>
     tidyr::unite(
       col = "term",
       sep = " * ",
       dplyr::all_of(names(variables$by)),
       dplyr::starts_with("contrast")
-    ) %>%
+    ) |>
     dplyr::relocate("variable", "term")
 
   if ("group" %in% names(res)) {
-    res <- res %>%
-      dplyr::rename(y.level = "group") %>%
+    res <- res |>
+      dplyr::rename(y.level = "group") |>
       dplyr::relocate("y.level")
   }
 
@@ -1074,16 +1067,22 @@ tidy_marginal_contrasts <- function(x, variables_list = "auto",
 }
 
 #' @export
-#' @param model a model
-#' @param interactions should combinations of variables corresponding to
-#' interactions be returned?
-#' @param cross if `interaction` is `TRUE`, should "cross-contrasts" be
+#' @param model (a model object, e.g. `glm`)\cr
+#' A model.
+#' @param interactions (`logical`)\cr
+#' Should combinations of variables corresponding to interactions be returned?
+#' @param cross (`logical`)\cr
+#' If `interaction` is `TRUE`, should "cross-contrasts" be
 #' computed? (if `FALSE`, only the last term of an interaction is passed to
 #' `variable` and the other terms are passed to `by`)
-#' @param var_categorical default `variable` value for categorical variables
-#' @param var_continuous default `variable` value for continuous variables
-#' @param by_categorical default `by` value for categorical variables
-#' @param by_continuous default `by` value for continuous variables
+#' @param var_categorical ([`predictor values`][marginaleffects::comparisons()])\cr
+#' Default `variable` value for categorical variables.
+#' @param var_continuous ([`predictor values`][marginaleffects::comparisons()])\cr
+#' Default `variable` value for continuous variables.
+#' @param by_categorical ([`predictor values`][marginaleffects::comparisons()])\cr
+#' Default `by` value for categorical variables.
+#' @param by_continuous ([`predictor values`][marginaleffects::comparisons()])\cr
+#' Default `by` value for continuous variables.
 #' @rdname tidy_marginal_contrasts
 variables_to_contrast <- function(model,
                                   interactions = TRUE,
@@ -1092,7 +1091,7 @@ variables_to_contrast <- function(model,
                                   var_continuous = 1,
                                   by_categorical = unique,
                                   by_continuous = stats::fivenum) {
-  variables <- model %>%
+  variables <- model |>
     model_list_variables(add_var_type = TRUE)
 
   if (interactions) {
@@ -1101,7 +1100,7 @@ variables_to_contrast <- function(model,
     keep <- variables[variables$var_type != "interaction", ]$variable
   }
 
-  response_variable <- model %>% model_get_response_variable()
+  response_variable <- model |> model_get_response_variable()
   if (!is.null(response_variable)) {
     keep <- keep[keep != response_variable]
   }
@@ -1116,11 +1115,11 @@ variables_to_contrast <- function(model,
     dichotomous = by_categorical,
     continuous = by_continuous
   )
-  variables <- variables %>%
+  variables <- variables |>
     tibble::column_to_rownames("variable")
 
   one_element <- function(v) {
-    v <- strsplit(v, ":") %>% unlist()
+    v <- strsplit(v, ":") |> unlist()
     if (length(v) == 1 || isTRUE(cross)) {
       one_variables <- variables[v, "var_type"]
       one_variables <- var_ret[one_variables]
