@@ -2,18 +2,19 @@ test_that("Attach and Detach models works", {
   mod <- lm(Sepal.Length ~ Sepal.Width + Species, data = iris)
   expect_identical(
     mod,
-    mod %>% tidy_and_attach() %>% tidy_get_model()
+    mod |> tidy_and_attach(model_matrix_attr = FALSE) |> tidy_get_model()
   )
 
   tb <- broom::tidy(mod)
-  expect_equivalent(
+  expect_equal(
     tb,
-    tb %>% tidy_attach_model(mod) %>% tidy_detach_model()
+    tb |> tidy_attach_model(mod) |> tidy_detach_model(),
+    ignore_attr = TRUE
   )
 
   # an error should occur if 'exponentiate = TRUE' for a linear model
   expect_error(
-    mod %>% tidy_and_attach(exponentiate = TRUE)
+    mod |> tidy_and_attach(exponentiate = TRUE)
   )
 })
 
@@ -30,6 +31,6 @@ test_that("tidy_and_attach() handles models without exponentiate arguments", {
     auto.var = TRUE, auto.fix.first = TRUE,
     auto.cov.lv.x = TRUE
   )
-  expect_error(mod %>% tidy_and_attach(exponentiate = TRUE))
-  expect_error(mod %>% tidy_and_attach(), NA)
+  expect_error(mod |> tidy_and_attach(exponentiate = TRUE))
+  expect_no_error(mod |> tidy_and_attach())
 })
