@@ -1,10 +1,10 @@
 test_that("tidy_remove_intercept() works for basic models", {
   mod <- glm(response ~ stage + grade + trt, gtsummary::trial, family = binomial)
-  res <- mod %>%
-    tidy_and_attach() %>%
+  res <- mod |>
+    tidy_and_attach() |>
     tidy_remove_intercept()
   expect_equal(
-    res %>% dplyr::filter(var_type == "intercept") %>% nrow(),
+    res |> dplyr::filter(var_type == "intercept") |> nrow(),
     0L
   )
 })
@@ -13,11 +13,10 @@ test_that("tidy_remove_intercept() works for basic models", {
 test_that("test tidy_remove_intercept() checks", {
   mod <- glm(response ~ stage + grade + trt, gtsummary::trial, family = binomial)
   # expect an error if no model attached
-  expect_error(mod %>% broom::tidy() %>% tidy_remove_intercept())
+  expect_error(mod |> broom::tidy() |> tidy_remove_intercept())
 
   # could be apply twice (no error)
-  expect_error(
-    mod %>% tidy_and_attach() %>% tidy_remove_intercept() %>% tidy_remove_intercept(),
-    NA
+  expect_no_error(
+    mod |> tidy_and_attach() |> tidy_remove_intercept() |> tidy_remove_intercept()
   )
 })
